<?php
/*
Plugin Name: Page Lock
Description: With this plugin you can limit changes in page options, deleting, creating selected pages.
Version: 1.03
Author: Michał Gańko
Author URI: http://foureyes.pl
*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 
	'Page Lock', 	
	'1.03', 		
	'Michał Gańko',
	'http://foureyes.pl', 
	'With this plugin you can limit changes in page options, deleting, creating selected pages.',
	'plugins',
	'page_lock_admin_tab'  
);


add_action('edit-extras','page_lock_on_edit_extras'); 
add_action('pages-main','page_lock_on_pages_main'); 
add_action('header','page_lock_on_header'); 

add_action('plugins-sidebar', 'createSideMenu', array($thisfile, 'Configure Page Lock'));

//delete lock security check
if (basename($_SERVER['PHP_SELF'])=='deletefile.php') {
	 if (isset($_GET['id'])) { 
		 $id = $_GET['id'];
		 $settings = page_lock_get_settings();
		 if ($settings->delete_lock && in_array($id , $settings->delete_slugs)){
			die('Page Lock plugin: delete lock!');
		 }
	 }
}

//page options lock security check and creating page lock security check
if (basename($_SERVER['PHP_SELF'])=='changedata.php') {

	$settings = page_lock_get_settings();
	
	if ( isset($_POST['existing-url']) ){ //if editing currently existing page
	
		$oldSlug = $_POST['existing-url'];
		$newSlug = $_POST['post-id'];
		
		if (in_array($oldSlug , $settings->options_slugs)){
		
			$file = GSDATAPAGESPATH . $oldSlug .".xml";
			$oldData = getXML($file);

			if ($settings->slug_lock && $oldSlug != $newSlug){
				die('Page Lock plugin: slug lock!');
			}
			if ($settings->visibility_lock && $_POST['post-private'] != (string)$oldData->private){
				die('Page Lock plugin: visibility lock!');
			}	
			if ($settings->template_lock && $_POST['post-template'] != (string)$oldData->template){
				die('Page Lock plugin: template lock!');
			}	
			if ($settings->parent_lock && $_POST['post-parent'] != (string)$oldData->parent){
				die('Page Lock plugin: parent lock!');
			}	
		}
	}
	else if (!isset($_POST['existing-url'])){ //if creating new page
		if (($settings->create_lock && !$settings->special_pages_enabled) || 
				($settings->create_lock && $settings->special_pages_enabled && !in_array($_POST['post-special'] , $settings->special_types))){
			die('Page Lock plugin: create page lock!');
		}
	}
}

//create lock, cloning page security check
if (basename($_SERVER['PHP_SELF'])=='pages.php') {
	 if ( @$_GET['action'] == 'clone' ) { 
		 $id = $_GET['id'];
		 
		 $file = GSDATAPAGESPATH . $id .".xml";
		 $oldData = getXML($file);
		 
		 if ($oldData){
			 $settings = page_lock_get_settings();
			 if (($settings->create_lock && !$settings->special_pages_enabled) || (
					$settings->create_lock && $settings->special_pages_enabled && !in_array($id , $settings->special_types))){
				die('Page Lock plugin: create pages lock!');
			 }
		 }
	 }
}



function page_lock_admin_tab() {
	if (isset($_POST['options_slugs'])){ //is post
	
		$visibility_lock = !empty($_POST['visibility_lock'])?1:0;
		$template_lock = !empty($_POST['template_lock'])?1:0;
		$parent_lock = !empty($_POST['parent_lock'])?1:0;
		$slug_lock = !empty($_POST['slug_lock'])?1:0;
		
		$delete_lock = !empty($_POST['delete_lock'])?1:0;
		$create_lock = !empty($_POST['create_lock'])?1:0;
		$special_pages_enabled = !empty($_POST['special_pages_enabled'])?1:0;
		
		$success = page_lock_save_settings(	$visibility_lock, 
											$template_lock,
											$parent_lock,
											$slug_lock,
											$_POST['options_slugs'],
											$delete_lock,
											$_POST['delete_slugs'],
											$create_lock,
											$special_pages_enabled,
											$_POST['special_types']
										);
	}

	$settings = page_lock_get_settings();
	
	require_once('PageLock/form_template.php');
}

//removes private button from i18n_navigation Edit Navigation Structure option
function page_lock_on_header(){

	if (basename($_SERVER['PHP_SELF'])!=='index.php') { //only on backend
		
		$settings = page_lock_get_settings();
		$script = '<script>$( document ).ready(function() {';
		
		echo '<style type="text/css">#sidebar{display:none}</style>'; //hide sidebar for changes
		if ($settings->create_lock){
			$script .= '$(\'#sb_newpage\').remove();';
			
			if (!$settings->special_pages_enabled){ //remove Create special page on sidebar
				$script .= '$(\'#sidebar li a[href="load.php?id=i18n_specialpages&create"]\').remove();';
			}
		}
		$script .= '$(\'#sidebar\').show();'; //show sidebar after changes

		if (basename($_SERVER['PHP_SELF'])=='load.php') {
		
			//i18n Multilevel navigation plugin
			if (@$_GET['id'] == 'i18n_navigation')  { 		
				if (!$settings->visibility_lock)
					return;
				
				if (empty($_POST)){ //no POST data, showing structure
					
					$len = count($settings->options_slugs);
					if ($len){
						foreach ($settings->options_slugs as $value)
						{
							$script .='$(\'#editnav tr#tr-'.$value.' a.togglePrivate\').remove();';
						}
					}
				}
				
				//page options lock security check when saving data from Edit Navigation Structure
				if (!empty($_POST['save'])){ //saving
				
					for ($i=0; isset($_POST['page_'.$i.'_url']); $i++) {
						$slug = $_POST['page_'.$i.'_url'];
						if (in_array($slug , $settings->options_slugs)){
							$file = GSDATAPAGESPATH . $slug .".xml";
							$oldData = getXML($file);

							if ($_POST['page_'.$i.'_private'] !== (string)$oldData->private)
								die('Page Lock plugin: private lock (i18n_navigation)!');
						}
					}
				}	
			}
		
			//i18n base plugin support, disables create page buttons
			if (@$_GET['id'] == 'i18n_base')  { 	
			
				echo '<style type="text/css">#maincontent{display:none}</style>';
				if ($settings->create_lock){
					if ($settings->special_pages_enabled){ //some specials are enabled
						$script .= '
						var pl_allowed = ['.'"'.implode('","', $settings->special_types).'"'.'],
							pl_reg = /&metak=_special_(.+)%2C/;
						$(\'#editpages tbody tr\').each(function(){
							var $tr = $(this),
								$a = $tr.find(\'td.secondarylink a[href^="edit.php?newid="]\'),
								res =  pl_reg.exec($a.attr(\'href\'));
			
							if (!res || (res && $.inArray(res[1], pl_allowed) == -1) ){
								$a.remove();
							}
						});
						';
					}
					else{ //remove all create buttons, no specials allowed
						$script .= '$(\'#editpages tbody tr td.secondarylink a[href^="edit.php?newid="]\').remove();';
					}
				}
				
				if ($settings->delete_lock){ //if delete lock activated, remove delete buttons
					$len = count($settings->delete_slugs);
					if ($len){
						foreach ($settings->delete_slugs as $value)
						{
							$script .= '$(\'a.i18n-delconfirm[href^="deletefile.php?id='.$value.'&"]\').remove();';
						}
					}
				}
				$script .= '$(\'#maincontent\').show();';
			}
			 
			
			//specialpages operations
			if (@$_GET['id'] == 'i18n_specialpages')  { 
				//hide content, wait untli js complete all deletions
				echo '<style type="text/css">#maincontent{display:none}</style>';
			
				if (isset($_GET['pages']) && isset($_GET['special'])){ //browsing pages by special type
					
					if ($settings->delete_lock){ //if delete lock activated, remove delete buttons
						$len = count($settings->delete_slugs);
						if ($len){
							foreach ($settings->delete_slugs as $value)
							{
								$script .= '$(\'a[href^="deletefile.php?id='.$value.'&"]\').remove();';
							}
						}
					}
					
					if ( !in_array($_GET['special'] , $settings->special_types) ){ //if not allowed delete Add New Page Link
						$script .= '$(\'a[href="edit.php?special='.$_GET['special'].'"]\').remove();';
					}
				}
				else if ( isset($_GET['pages']) ){  //show all available special types
					if ($settings->create_lock){
					
						if ($settings->special_pages_enabled){ //some specials are enabled
							$script .= '
							var pl_allowed = ['.'"'.implode('","', $settings->special_types).'"'.'];
							$(\'#editspecial tbody tr\').each(function(){
								var $tr = $(this),
									$a = $tr.find(\'td a[href^="edit.php?special="]\');
				
								if ($.inArray($a.attr(\'href\').replace("edit.php?special=", ""), pl_allowed) == -1 ){
									$a.remove();
								}
							});
							';
						}
						else{ //remove all create buttons, no specials allowed
							$script .= '$(\'#editspecial tbody tr td a[href^="edit.php?special="]\').remove();';
						}
					}
					
				}
				else if ( isset($_GET['create']) ){ //Create New Special Page, list of special pages types
					if ($settings->create_lock && $settings->special_pages_enabled){ //remove all rows that are not allowed
						$script .= '
						var pl_allowed = ['.'"'.implode('","', $settings->special_types).'"'.'];
						$(\'#editspecial tbody tr\').each(function(){
							var $tr = $(this),
								$a = $tr.find(\'td a\');
			
							if ( $.inArray($a.attr(\'href\').replace("edit.php?special=", ""), pl_allowed) == -1 ){
								$tr.remove();
							}
						});
						';
					}
				}
				
				$script .= '$(\'#maincontent\').show();';
				
			}	
			 
		}

		$script .= '});</script>';
		
		echo $script;
	}
}

//removes delete buttons from pages list
function page_lock_on_pages_main() {
	$settings = page_lock_get_settings();
	
	$script = '<script>$( document ).ready(function() {';
	
	//if on restriction list, disable delet ebutton on pages list
	$len = count($settings->delete_slugs);
	if ($settings->delete_lock && $len){
		foreach ($settings->delete_slugs as $value)
		{
		  $script .= '$(\'#editpages a.delconfirm[href^="deletefile.php?id='.$value.'&"]\').remove();';
		}
	}
	
	$script .= '});</script>';
	
	echo $script;
}

//disables page option fields
function page_lock_on_edit_extras() {
	global $url; //here is slug
	
	$settings = page_lock_get_settings();
	
	$script = '<script>$( document ).ready(function() {';
	
	//prepare page options
	if (in_array($url , $settings->options_slugs)){
		if ($settings->slug_lock){
			$script .= '$("#post-id").attr("readonly", "readonly");';
		}	
		if ($settings->visibility_lock){
			$script .= '$("#post-private").attr("disabled", "disabled");';
		}	
		if ($settings->parent_lock){
			$script .= '$("#post-parent").attr("disabled", "disabled");';
		}		
		if ($settings->template_lock){
			$script .= '$("#post-template").attr("disabled", "disabled");';
		}
		
		//remove disabled attribute before submitting, for sending POST data
		$script .= '
			$(\'#editform\').bind(\'submit\', function() {
				$(this).find(\'select\').removeAttr(\'disabled\');
			});
		';
		
	}
	
	//disable delete option from dropdown next to save button
	if ($settings->delete_lock && in_array($url , $settings->delete_slugs)){
		$script .= '$(\'li a[href^="deletefile.php?id='.$url.'&"]\').remove();';
	}	
	
	//disable clone option from dropdown next to save button
	if ($settings->create_lock){
		global $data_edit; //SimpleXML to read from

		if ($settings->special_pages_enabled && in_array((string)$data_edit->special , $settings->special_types)){ 
		}
		else{
			$script .= '$(\'li a[href^="pages.php?id='.$url.'&action=clone"]\').remove();';
		}
	}
	
	$script .= '});</script>'; //close script
	
	echo $script;
}

//retrieves settings from xml
function page_lock_get_settings() {
    $file = GSDATAOTHERPATH . 'pagelock.xml';
	
	if (!file_exists($file)) {
		page_lock_save_settings(); //create empty one
	}
	
	$data = getXML($file);
	
	$settings = new stdClass();

	$settings->visibility_lock = (bool) (string) $data->visibility_lock;
	$settings->template_lock = (bool) (string) $data->template_lock;
	$settings->parent_lock = (bool) (string) $data->parent_lock;
	$settings->slug_lock = (bool) (string) $data->slug_lock;
	
	$settings->options_slugs = explode(',',(string)$data->options_slugs);

	$settings->delete_lock = (bool) (string) $data->delete_lock;
	$settings->delete_slugs =  explode(',',(string)$data->delete_slugs);	
	
	$settings->create_lock = (bool) (string) $data->create_lock;
	$settings->special_pages_enabled = (bool) (string) $data->special_pages_enabled;
	$settings->special_types =  explode(',',(string)$data->special_types);
	
	return $settings;
}

//saves settings to xml
function page_lock_save_settings(	$visibility_lock = 0,
									$template_lock = 0, 
									$parent_lock = 0,
									$slug_lock = 0,
									$options_slugs = '',
									$delete_lock = 0, 
									$delete_slugs = '',
									$create_lock = 0, 
									$special_pages_enabled = 0, 
									$special_types = '' 
								) {
    $file = GSDATAOTHERPATH . 'pagelock.xml';
	
	$xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><settings></settings>');
	$xml->addChild('visibility_lock', $visibility_lock);
	$xml->addChild('template_lock', $template_lock);
	$xml->addChild('parent_lock', $parent_lock);
	$xml->addChild('slug_lock', $slug_lock);
	
	$xml->addChild('delete_lock', $delete_lock);
	
	$obj = $xml->addChild('options_slugs');
	$obj->addCData($options_slugs);	
	
	$obj = $xml->addChild('delete_slugs');
	$obj->addCData($delete_slugs);
	
	$xml->addChild('create_lock', $create_lock);
	$xml->addChild('special_pages_enabled', $special_pages_enabled);
	
	$obj = $xml->addChild('special_types');
	$obj->addCData($special_types);

	
	  # write data to file
	return XMLsave($xml, $file) === true ? true : false;
}